%define upstream_name    Server-Starter
%define upstream_version 0.35

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 5

Summary:    A superdaemon for hot-deploying server programs
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Server/%{upstream_name}-%{upstream_version}.tar.gz
BuildArch:  noarch

BuildRequires: perl(IO::Socket::IP)
BuildRequires: perl(Module::Build) >= 0.400.500
BuildRequires: perl(Net::EmptyPort)
BuildRequires: perl(Test::Requires)
BuildRequires: perl(Test::SharedFork)
BuildRequires: perl(Test::TCP) >= 2.80.0
BuildRequires: perl-devel
# For the tests

%description
It is often a pain to write a server program that supports graceful
restarts, with no resource leaks. Server::Starter, solves the
problem by splitting the task into two. One is start_server, a
script provided as a part of the module, which works as a superdaemon that
binds to zero or more TCP ports or unix sockets, and repeatedly spawns the
server program that actually handles the necessary tasks (for example,
responding to incoming connections). The spawned server programs under
Server::Starter call accept(2) and handle the requests.

To gracefully restart the server program, send SIGHUP to the superdaemon.
The superdaemon spawns a new server program, and if (and only if) it starts
up successfully, sends SIGTERM to the old server program.

By using Server::Starter it is much easier to write a
hot-deployable server. Following are the only requirements a server program
to be run under Server::Starter should conform to:

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=%{buildroot}
perl -i -lape 's{^#!perl\s*$}{#!%{_bindir}/perl} if $. == 1' %{buildroot}/%{_bindir}/start_server

%check
./Build test

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml
%license LICENSE
%{perl_vendorlib}/*
%{_mandir}/man3/*
%{_bindir}/start_server
%{_mandir}/man1/start_server.*


%changelog
* Fri Jun 27 2025 umeabot <umeabot> 0.350.0-5.mga10
+ Revision: 2206308
- Mageia 10 Mass Rebuild

* Mon Mar 21 2022 umeabot <umeabot> 0.350.0-4.mga9
+ Revision: 1812849
- Mageia 9 Mass Rebuild

* Wed Jul 01 2020 tv <tv> 0.350.0-3.mga8
+ Revision: 1600832
- no need for PERL_USE_UNSAFE_INC=1

* Sun Feb 16 2020 umeabot <umeabot> 0.350.0-2.mga8
+ Revision: 1533569
- Mageia 8 Mass Rebuild

* Mon Sep 23 2019 tv <tv> 0.350.0-1.mga8
+ Revision: 1444714
- update to 0.35

* Thu Sep 20 2018 umeabot <umeabot> 0.340.0-2.mga7
+ Revision: 1285989
- Mageia 7 Mass Rebuild

* Wed Mar 07 2018 shlomif <shlomif> 0.340.0-1.mga7
+ Revision: 1207258
- update to 0.34

* Sun Jul 30 2017 sander85 <sander85> 0.330.0-1.mga7
+ Revision: 1132783
- update to 0.33
+ tv <tv>
- package LICENSE
- use %%_mandir
- fix testsuite: BR perl-devel + some BRs for tests
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sun Sep 06 2015 sander85 <sander85> 0.320.0-1.mga6
+ Revision: 873698
- update to 0.32

* Mon Jul 20 2015 sander85 <sander85> 0.310.0-1.mga6
+ Revision: 855713
- update to 0.31

* Fri Jul 17 2015 shlomif <shlomif> 0.300.0-3.mga6
+ Revision: 854929
- Disable the tests
- Fix the shabanag on the executable

* Sun Jul 05 2015 sander85 <sander85> 0.300.0-1.mga6
+ Revision: 851085
- update to 0.30

* Sun Oct 19 2014 umeabot <umeabot> 0.170.0-4.mga5
+ Revision: 790401
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.170.0-3.mga5
+ Revision: 750725
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.170.0-2.mga5
+ Revision: 686188
- Mageia 5 Mass Rebuild

* Sat Feb 08 2014 sander85 <sander85> 0.170.0-1.mga5
+ Revision: 586187
- Try make instead of %%make
- update to 0.17

* Tue Jan 07 2014 dmorgan <dmorgan> 0.150.0-3.mga4
+ Revision: 565306
- Rebuild to please autobuild

* Sat Oct 19 2013 umeabot <umeabot> 0.150.0-2.mga4
+ Revision: 530264
- Mageia 4 Mass Rebuild

* Sun Jul 21 2013 sander85 <sander85> 0.150.0-1.mga4
+ Revision: 456948
- update to 0.15

* Wed Jun 26 2013 jquelin <jquelin> 0.140.0-1.mga4
+ Revision: 447088
- update to 0.14

* Sun Jan 13 2013 umeabot <umeabot> 0.120.0-2.mga3
+ Revision: 372585
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 26 2012 jquelin <jquelin> 0.120.0-1.mga3
+ Revision: 298107
- update to 0.12
- imported package perl-Server-Starter


* Mon Jul 25 2011 cpan2dist 0.11-1mga
- initial mageia release, generated with cpan2dist
